WifiManagerImpl class
Connects and disconnects Wi-Fi networks using plugin_wifi_connect.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connect(
String ssid, {bool saveNetwork = false}) → Future< bool?> -
Connects to an open Wi-Fi network by SSID.
override
-
connectByPrefix(
String ssidPrefix, {bool saveNetwork = false}) → Future< bool?> -
Connects to an open Wi-Fi network whose SSID starts with
ssidPrefix.override -
connectToSecureNetwork(
String ssid, String password, {bool isWep = false, bool isWpa3 = false, bool saveNetwork = false, bool isHidden = false}) → Future< bool?> -
Connects to a secured Wi-Fi network by SSID and password.
override
-
connectToSecureNetworkByPrefix(
String ssidPrefix, String password, {bool isWep = false, bool isWpa3 = false, bool saveNetwork = false}) → Future< bool?> -
Connects to a secured Wi-Fi network whose SSID starts with
ssidPrefix.override -
disconnect(
) → Future< bool?> -
Disconnects from the current Wi-Fi network.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited